@@ -7,9 +7,10 @@
 #ifndef FILEFORMATINTERFACE_H
 #define FILEFORMATINTERFACE_H
 
-#include <QObject>
-#include "typenames.h"
 #include "graphtheory_export.h"
+#include "typenames.h"
+#include <KPluginMetaData>
+#include <QObject>
 
 class QUrl;
 
@@ -37,26 +38,13 @@ public:
     /**
      * Describes the last error of the plugin.
      */
-    enum Error {
-        None,
-        Unknown,
-        FileIsReadOnly,
-        CouldNotOpenFile,
-        NoGraphFound,
-        EncodingProblem,
-        CouldNotRecognizeFileFormat,
-        NotSupportedOperation
-    };
+    enum Error { None, Unknown, FileIsReadOnly, CouldNotOpenFile, NoGraphFound, EncodingProblem, CouldNotRecognizeFileFormat, NotSupportedOperation };
 
     /**
      * Describes the capability of the plugin, i.e., if the plugin can be used
      * to read and/or write files.
      */
-    enum PluginType {
-        ImportOnly,
-        ExportOnly,
-        ImportAndExport
-    };
+    enum PluginType { ImportOnly, ExportOnly, ImportAndExport };
 
     /**
      * Constructor.
@@ -64,7 +52,7 @@ public:
      * \param aboutData is description of the plugin
      * \param parent is the object parent
      */
-    FileFormatInterface(const QString &componentName, QObject* parent);
+    FileFormatInterface(QObject *parent, const KPluginMetaData &data);
     ~FileFormatInterface() override;
 
     /**
@@ -133,7 +121,6 @@ public:
      */
     virtual GraphDocumentPtr graphDocument() const;
 
-
 protected:
     /**
      * \internal
@@ -141,7 +128,7 @@ protected:
      *
      * \return file that is last used for write/read
      */
-    const QUrl & file() const;
+    const QUrl &file() const;
 
     /**
      * \internal
