@@ -13,14 +13,13 @@
 namespace GraphTheory
 {
 
-
 /** \brief the Rocs new generation graph file format
  */
 class Rocs2FileFormat : public FileFormatInterface
 {
     Q_OBJECT
 public:
-    explicit Rocs2FileFormat(QObject *parent, const QList< QVariant >&);
+    explicit Rocs2FileFormat(QObject *parent, const KPluginMetaData &data, const QVariantList &);
     ~Rocs2FileFormat() override;
 
     /**
